import os
import os.path
import sys
import platform


#-----------------------------------------------------------------------------------------
#                       Start of main init scrip
#  This initializes (just) the SasktranIF module (_sasktranif.pyd) to use the python
#  environment registry. All other Sasktran C++ modules will be automatically initialized to use
#  the python environment registry when they are loaded by the _sasktranif.pyd code. For this to work
#  properly each module must invoke sasktranif.sasktranif.SKTRAN_IFCreateRegistryEntriesForDLL(dllname, paramstr)
#  as part of the installation procedure. An example of configuring the regsitry can be found in installcorecomponents.py
#
#-----------------------------------------------------------------------------------------

def check_installation_called_from_sasktranif( SKTRAN_IFCreateRegistryEntriesForDLL, registry ):
    filename = sys.modules["sktran_disco"].__file__                                          # Get the filename of the sasktranif.py file
    dirname  = os.path.dirname(filename)                                                      # Now get the directory of that file
    flagname = dirname + os.sep + "first_time_createregistry.txt"

    if os.path.exists(flagname):
        if platform.system() == 'Windows':
            dllname = dirname + os.sep + 'isk_disco.dll'
        else:
            dllname = dirname + os.sep + 'libisk_disco.so'

        paramstr = dllname
        SKTRAN_IFCreateRegistryEntriesForDLL(dllname, paramstr)
        os.unlink(flagname)

from ._version import get_versions
__version__ = get_versions()['version']
del get_versions
